/**
 * Sonatype Nexus (TM) Open Source Version
 * Copyright (c) 2007-2012 Sonatype, Inc.
 * All rights reserved. Includes the third-party code listed at http://links.sonatype.com/products/nexus/oss/attributions.
 *
 * This program and the accompanying materials are made available under the terms of the Eclipse Public License Version 1.0,
 * which accompanies this distribution and is available at http://www.eclipse.org/legal/epl-v10.html.
 *
 * Sonatype Nexus (TM) Professional Version is available from Sonatype, Inc. "Sonatype" and "Sonatype Nexus" are trademarks
 * of Sonatype, Inc. Apache Maven is a trademark of the Apache Software Foundation. M2eclipse is a trademark of the
 * Eclipse Foundation. All other trademarks are the property of their respective owners.
 */
package org.sonatype.nexus.plugins.capabilities.internal;

import static com.google.common.base.Preconditions.checkNotNull;

import java.util.List;
import javax.inject.Inject;
import javax.inject.Named;
import javax.inject.Singleton;

import org.sonatype.nexus.plugins.capabilities.CapabilityDescriptor;
import org.sonatype.nexus.plugins.capabilities.CapabilityDescriptorRegistry;
import org.sonatype.nexus.plugins.capabilities.CapabilityType;

@Named
@Singleton
class DefaultCapabilityDescriptorRegistry
    implements CapabilityDescriptorRegistry
{

    private final List<CapabilityDescriptor> descriptors;

    @Inject
    DefaultCapabilityDescriptorRegistry( final List<CapabilityDescriptor> descriptors )
    {
        this.descriptors = checkNotNull( descriptors );
    }

    @Override
    public CapabilityDescriptor get( final CapabilityType capabilityType )
    {
        for ( final CapabilityDescriptor descriptor : descriptors )
        {
            if ( descriptor.type().equals( capabilityType ) )
            {
                return descriptor;
            }
        }
        return null;
    }

    @Override
    public CapabilityDescriptor[] getAll()
    {
        return descriptors.toArray( new CapabilityDescriptor[descriptors.size()] );
    }
}
